@@ -26,25 +26,25 @@ import argparse
 import traceback
 import logging
 
-from PySide6 import QtCore, QtWidgets
+from PySide6 import QtWidgets
 from PySide6.QtUiTools import loadUiType
 from PySide6.QtWidgets import QMessageBox
 from PySide6.QtCore import Signal
 import zarr
 
-from . busydialog import BusyDialog
-
-
 # This is a workaround for loadUiType not finding the resource _rc.py inside the package
 sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))
 
+from signalstorage import signals
+from busydialog import BusyDialog
+
 _log = logging.getLogger(__name__)
 
 
 def exception_handler(extype, value, tb):
     """
     Global handler for exceptions.
-    Not particuarly smart, but stops crashes from minor recoverable errors.
+    Not particularly smart, but stops crashes from minor recoverable errors.
     The exception details are sent to the log.
     """
     logging.error("Caught an unhandled exception:\n  " + "  ".join(traceback.format_exception(extype, value, tb)).rstrip("\n"))
@@ -122,7 +122,7 @@ class MainWindow(QtWidgets.QMainWindow, loadUiType(__file__.split(".py")[0] + ".
         if not self.ds.prompt_unsaved(parent=self):
             return
         self.ds.new_raw_zarr(location=None)
-        self.ds.signals.data_changed.emit(False) # Don't update UI controls
+        signals.data_changed.emit(False) # Don't update UI controls
         self.actionSaveAs.setEnabled(False)
         self.menuExport.setEnabled(False)
         self.actionProperties.setEnabled(False)
@@ -139,7 +139,7 @@ class MainWindow(QtWidgets.QMainWindow, loadUiType(__file__.split(".py")[0] + ".
             QMessageBox.critical(self, "Error opening data directory", f"{ex}")
             return
         if not dirname: return
-        self.ds.signals.data_changed.emit(True)
+        signals.data_changed.emit(True)
         self.actionSaveAs.setEnabled(True)
         self.menuExport.setEnabled(True)
         self.actionProperties.setEnabled(True)
@@ -173,7 +173,7 @@ class MainWindow(QtWidgets.QMainWindow, loadUiType(__file__.split(".py")[0] + ".
         if not filename: return
         self.ds.d = data
         self.ds.t = zarr.group()
-        self.ds.signals.data_changed.emit(True)
+        signals.data_changed.emit(True)
         self.actionSaveAs.setEnabled(True)
         self.menuExport.setEnabled(True)
         self.actionProperties.setEnabled(True)
