@@ -189,8 +189,8 @@ class Acquisition():
     """
     Parent class of all acquisition class plugins.
 
-    Every acquisition driver class should derive from this parent, so that the 
-    automatic device class discovery can function.
+    Every acquisition driver class should derive from this parent, so that the automatic device
+    class discovery can function.
     """
     def __init__(self, **kwargs):
 
@@ -199,12 +199,6 @@ class Acquisition():
 
         #: Description of this acquisition device.
         self.description = "Unknown Acquisition Method"
-
-        #: Set of functions to call on to indicate updates have been made to the data set.
-        self._update_callbacks = set()
-
-        #: Set of functions to call when acquisition is completed.
-        self._completion_callbacks = set()
        
     def close(self) -> None:
         """
@@ -218,70 +212,34 @@ class Acquisition():
         """
         return True
     
-    def register_update_callback(self, callback: callable) -> None:
-        """
-        Register a function to receive notifications for updates to the raw data set.
-
-        The callback method should take the form of ``update_callback(scans_i, times_i, wls_i)``,
-        where ``scans_i``, ``times_i`` and ``wls_i`` are lists or slices indicating the array
-        indicies from the `"raw/data"` element in :data:`datastorage.d`.
-        If any of the parameters are ``None``, it indicates all the data in that array axis has
-        potentially changed.
-
-        :param callback: Function to call when raw data is updated.
-        """
-        if callable(callback):
-            self._update_callbacks.add(callback)
-        else:
-            raise RuntimeError("Attempted to register non-callable function for update callbacks.")
-    
-    def unregister_update_callback(self, callback: callable) -> None:
-        """
-        Unregister a function previously registered to receive spectrum callbacks using
-        :meth:`register_update_callback`.
-
-        :param callback: Function to unregister.
-        """
-        if callback in self._update_callbacks:
-            self._update_callbacks.remove(callback)
-        else:
-            raise RuntimeWarning("Attempted to unregister an unknown function for update callbacks.")
-
-    def register_completion_callback(self, callback: callable) -> None:
-        """
-        Register a function to receive notifications for completion of acquisition.
-
-        The callback method should take the form of ``completion_callback(error=None)``, with
-        ``error`` being an :class:`Exception` describing any error code. The exception may be of
-        type :class:`AcquisitionException` to indicate the error was due to something identifiable
-        (for example, a device error), but a generic exception may be returned if the acquisition
-        thread detects some other unknown error condition.  ``None`` indicates acquisition was
-        completed successfully.
-
-        :param callback: Function to call on completion of acquisition.
-        """
-        self._completion_callbacks.add(callback)
-    
-    def unregister_completion_callback(self, callback: callable) -> None:
-        """
-        Unregister a function previously registered to receive acquisition completion callbacks using
-        :meth:`register_completion_callback`.
-
-        :param callback: Function to unregister.
-        """
-        if callback in self._completion_callbacks:
-            self._completion_callbacks.remove(callback)
-        else:
-            raise RuntimeWarning("Attempted to unregister an unknown function for acquisition completion callbacks.")
-
     def start(self) -> None:
         """
         Begin acquisition of data.
 
         It is up to the sub-classes implementing this method to determine what and how much data
-        should be obtained in whatever manner is appropriate.
-        For example, the data range and number of scans can be extracted from the :class:`DataPanel`
-        user interface.
+        should be obtained in whatever manner is appropriate. For example, the data range and number
+        of scans can be extracted from the :class:`DataPanel` user interface.
+
+        During acquisition, the presence of new data points can be communicated to other components
+        by emitting the :data:`~trspectrometer.signals.raw_data_updated` Signal. Parameters can be
+        used to specify which points in the data set have changed to allow more efficient re-drawing
+        for example.
+
+        Upon completion of the acquisition, the :data:`~trspectrometer.signals.acquisition_stopped`
+        Signal should be emitted to notify other components. If an error occurred, an Exception
+        instance can be passed to provide further information. For example:
+
+        .. code-block:: python
+
+            from signalstorage import signals
+            from utils import AcquisitionError
+            
+            if error:
+                # Acquisition completed with some error
+                signals.acquisition_stopped.emit(AcquisitionError("Something bad happened."))
+            else:
+                # Acquisition completed OK
+                signals.acquisition_stopped.emit(None)
         """
         pass
 
