@@ -19,9 +19,9 @@ from time import sleep, monotonic
 import warnings
 
 import numpy as np
-import zarr
 
 import configuration as config
+from signalstorage import signals
 import hardware as hw
 import datastorage as ds
 from utils import AcquisitionError, AcquisitionAbortedWarning, no_infs, status_message, si_unit_factor, now_string
@@ -232,7 +232,7 @@ class TA_SweptAcquisition(Acquisition):
         ds.d["raw"].attrs["config"] = config.data.copy()
 
         # Notify that the data structures have changed
-        ds.signals.data_changed.emit(False)  # Don't update UI
+        signals.data_changed.emit(False)  # Don't update UI
 
         # Start up the acquisition thread
         self._acq_thread = Thread(name="Acquisition", target=self._start_acq, kwargs={
@@ -497,11 +497,8 @@ class TA_SweptAcquisition(Acquisition):
                 sst.append([start_time, now_string()])
                 ds.d["raw/data"].attrs["start_stop_times"] = sst
 
-                # Notify that data has been updated
-                for cb in self._update_callbacks.copy():
-                    cb([s_i], sweep_ranges[:,0], None)
-                # And trigger the Qt data update signal
-                ds.signals.data_updated.emit([s_i], sweep_ranges[:,0], None)
+                # Trigger the data update signal
+                signals.raw_data_updated.emit([s_i], sweep_ranges[:,0], None)
 
                 # Increment scan index
                 s_i += 1
@@ -538,9 +535,7 @@ class TA_SweptAcquisition(Acquisition):
             self._log.warning("Error stopping Chopper.")
 
         self._log.info("Stopped acquisition.")
-        # Iterate over copy of callbacks set so it can be modified if needed
-        for cb in self._completion_callbacks.copy():
-            cb(error)
+        signals.acquisition_stopped.emit(error)
         self._acq_thread = None
 
             
