@@ -29,6 +29,7 @@ import numpy as np
 
 import pyqtgraph as pg
 import configuration as config
+from signalstorage import signals
 import hardware as hw
 import datastorage as ds
 from utils import AcquisitionError, AcquisitionAbortedWarning, no_infs, status_message, si_unit_factor
@@ -55,6 +56,7 @@ class ScopePanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")
 
         # Configure plot area
         self.plot = self.glw.addPlot(enableMenu=False)
+        self.plot.showGrid(x=True, y=True)
         self.plot.addLegend()
         self.zeroline = pg.InfiniteLine(pos=0.0, angle=0, pen=(64, 64, 64), movable=False)
         self.plot.addItem(self.zeroline)
@@ -63,6 +65,18 @@ class ScopePanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")
         self.reference_pinned = pg.PlotDataItem(pen=(192, 0, 0), name="Pinned")
         self.spectrum = self.plot.plot(pen=(255, 255, 0), name="Signal")
         self.plot.setLabels(left="Intensity (a.u.)", bottom="Wavelength (nm)")
+        # Cursor labels
+        self.cursor_label = pg.LabelItem(justify="right")
+        self.glw.addItem(self.cursor_label, row=1, col=0)
+        # Cursor crosshair
+        self.vline = pg.InfiniteLine(angle=90, movable=False, pen=config.data["scope"]["crosshair"]["colour"])
+        self.hline = pg.InfiniteLine(angle=0, movable=False, pen=config.data["scope"]["crosshair"]["colour"])
+        self.plot.addItem(self.vline, ignoreBounds=True)
+        self.plot.addItem(self.hline, ignoreBounds=True)
+        # Install signalproxy to filter mouse move events
+        self.sigproxy = pg.SignalProxy(self.plot.scene().sigMouseMoved, rateLimit=60, slot=self._mouse_moved)
+        # Catch mouse exit plot events
+        self.glw.installEventFilter(self)
 
         # Restore UI settings
         self._load_ui_config()
@@ -108,6 +122,8 @@ class ScopePanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")
             hw.modules["chopper"].add_change_callback(self._chopper_devices_changed)
         self._chopper_devices_changed()
         self.start()
+        # Be aware of laser reprate changes
+        signals.laser_reprate_changed.connect(self._reprate_changed)
 
 
     def hideEvent(self, event):
@@ -116,6 +132,8 @@ class ScopePanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")
 
         :param event: ``QEvent`` describing the event.
         """
+        # Don't care about laser reprate changes any more
+        signals.laser_reprate_changed.disconnect(self._reprate_changed)
         self.stop()
         # Unsubscribe from delay device changes if delay module loaded
         if "delay" in hw.modules and not hw.modules["delay"].devices[0] is None:
@@ -126,6 +144,37 @@ class ScopePanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")
         self._save_ui_config()
 
 
+    def _mouse_moved(self, event):
+        """
+        Handle mouse movements over plot, update cursor position and labels.
+        """
+        pos = event[0]
+        if self.plot.sceneBoundingRect().contains(pos):
+            mousePoint = self.plot.getViewBox().mapSceneToView(pos)
+            #index = int(mousePoint.x())
+            #if index > 0 and index < len(data1):
+            #    label.setText("<span style='font-size: 12pt'>x=%0.1f,   <span style='color: red'>y1=%0.1f</span>,   <span style='color: green'>y2=%0.1f</span>" % (mousePoint.x(), data1[index], data2[index]))
+            self.vline.setPen(config.data["scope"]["crosshair"]["colour"])
+            self.vline.setPos(mousePoint.x())
+            self.hline.setPen(config.data["scope"]["crosshair"]["colour"])
+            self.hline.setPos(mousePoint.y())
+            self.cursor_label.setText(f"Cursor at {mousePoint.x():0.1f} nm = {mousePoint.y():g}")
+        else:
+            self.vline.setPen([0, 0, 0, 0])
+            self.hline.setPen([0, 0, 0, 0])
+            self.cursor_label.setText("")
+
+
+    def eventFilter(self, obj, event):
+        if obj == self.glw:
+            if event.type() == QtCore.QEvent.Type.Leave:
+                # Hide crosshair when mouse leaves the plot window
+                self.vline.setPen([0, 0, 0, 0])
+                self.hline.setPen([0, 0, 0, 0])
+                self.cursor_label.setText("")
+        return False
+
+
     def _delay_devices_changed(self):
         """Notify that delay devices have changed state."""
         if "delay" in hw.modules and not hw.modules["delay"].devices[0] is None and hw.modules["delay"].devices[0].is_initialised():
@@ -213,6 +262,14 @@ class ScopePanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")
                 self.reference_deltaA.setZValue(-5)
 
 
+    def _reprate_changed(self):
+        """
+        Handle changes to laser reprate if currently acquiring.
+        """
+        self.stop()
+        self.start()
+        
+
     def start(self):
         """
         Start acquiring spectra.
@@ -365,12 +422,13 @@ class ScopePanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")
                 self._interface.start(2*n_samples)
 
                 # Wait for acquisition to finish
-                clock = monotonic()
+                acq_start_time = monotonic()
+                acq_expected_duration = 2*n_samples/config.data["hardware"]["laser_reprate"] + 1.0
                 acquisition_failure = False
                 while not (interface_done.is_set() and detector_done.is_set()):
                     if self._acq_stop.is_set():
                         raise AcquisitionAbortedWarning()
-                    if monotonic() > (clock + 5.0):
+                    if monotonic() > (acq_start_time + acq_expected_duration):
                         # TODO: Could decide on timeout value depending on number of samples and laser rep rate
                         acquisition_failure = True
                         break
