@@ -1,7 +1,7 @@
 import os
 
-from PySide2 import QtCore, QtWidgets
-from PySide2.QtCore import Qt     #pylint: disable=no-name-in-module
+from PySide6 import QtCore, QtWidgets
+from PySide6.QtCore import Qt
 
 class FlowLayout(QtWidgets.QLayout):
     """
